@@ -63,6 +63,7 @@ def _prepare_timeseries_settings(user_provided_settings):
         ,use_previous_target=True
         ,keep_order_column=True
         ,nr_predictions=1
+        ,historical_columns=[]
     )
 
     if len(user_provided_settings) > 0:
@@ -245,6 +246,7 @@ class Predictor:
                 data_split_indexes = advanced_args.get('data_split_indexes', None),
                 tags_delimiter = advanced_args.get('tags_delimiter', ','),
                 force_predict = advanced_args.get('force_predict', False),
+                mixer_class = advanced_args.get('use_mixers', None),
 
                 breakpoint = self.breakpoint,
                 setup_args = from_data.setup_args if hasattr(from_data, 'setup_args') else None
