@@ -1,3 +1,5 @@
+import os
+import sys
 import platform
 import re
 import pickle
@@ -6,9 +8,12 @@ from pathlib import Path
 import uuid
 from contextlib import contextmanager
 
-from sklearn.metrics import balanced_accuracy_score, accuracy_score, f1_score
-import os
-import sys
+from sklearn.metrics import (
+    balanced_accuracy_score,
+    accuracy_score,
+    f1_score,
+    r2_score
+)
 
 from mindsdb_native.__about__ import __version__
 from mindsdb_native.config import CONFIG
@@ -136,34 +141,43 @@ def get_value_bucket(value, buckets, col_stats, hmd=None):
     return bucket
 
 
-def evaluate_regression_accuracy(column, predictions, true_values, backend):
-    pred_confidence_intervals = predictions[f'{column}_confidence_range']
-
-    within_interval = 0
-    for true, interval in zip(true_values, pred_confidence_intervals):
-        if true >= interval[0] and true <= interval[1]:
-            within_interval += 1
-    return within_interval/len(true_values)
+def evaluate_regression_accuracy(
+        column,
+        predictions,
+        true_values,
+        backend,
+        use_conf_intervals=True,
+        **kwargs
+    ):
+    if use_conf_intervals:
+        pred_confidence_intervals = predictions[f'{column}_confidence_range']
+        within_interval = 0
+        for true, interval in zip(true_values, pred_confidence_intervals):
+            if true >= interval[0] and true <= interval[1]:
+                within_interval += 1
+        return within_interval/len(true_values)
+    else:
+        return r2_score(true_values, predictions[column])
 
 
-def evaluate_classification_accuracy(column, predictions, true_values, backend):
+def evaluate_classification_accuracy(column, predictions, true_values, **kwargs):
     pred_values = predictions[column]
     return balanced_accuracy_score(true_values, pred_values)
 
 
-def evaluate_multilabel_accuracy(column, predictions, true_values, backend):
+def evaluate_multilabel_accuracy(column, predictions, true_values, backend, **kwargs):
     encoder = backend.predictor._mixer.encoders[column]
     pred_values = encoder.encode(predictions[column])
     true_values = encoder.encode(true_values)
     return f1_score(true_values, pred_values, average='weighted')
 
 
-def evaluate_generic_accuracy(column, predictions, true_values, backend):
+def evaluate_generic_accuracy(column, predictions, true_values, **kwargs):
     pred_values = predictions[column]
     return accuracy_score(true_values, pred_values)
 
 
-def evaluate_accuracy(predictions, data_frame, col_stats, output_columns, backend=None, hmd=None):
+def evaluate_accuracy(predictions, data_frame, col_stats, output_columns, backend=None, **kwargs):
     column_scores = []
     for column in output_columns:
         col_type = col_stats[column]['typing']['data_type']
@@ -177,10 +191,16 @@ def evaluate_accuracy(predictions, data_frame, col_stats, output_columns, backen
                 evaluator = evaluate_classification_accuracy
         else:
             evaluator = evaluate_generic_accuracy
-        column_score = evaluator(column, predictions, data_frame[column], backend)
+        column_score = evaluator(
+            column,
+            predictions,
+            data_frame[column],
+            backend=backend,
+            **kwargs
+        )
         column_scores.append(column_score)
 
-    score = sum(column_scores)/len(column_scores) if column_scores else 0.
+    score = sum(column_scores) / len(column_scores) if column_scores else 0.0
     if score == 0:
         score = 0.00000001
     return score
