@@ -94,7 +94,7 @@ def clean_float(val):
     if isinstance(val, (int, float)):
         return float(val)
 
-    if isinstance(val, np.float64):
+    if isinstance(val, np.float):
         return val
 
     val = str(val).strip(' ')
@@ -119,15 +119,16 @@ def gen_chars(length, character):
 
 def cast_string_to_python_type(string):
     """ Returns None, an integer, float or a string from a string"""
-    try:
-        if string is None or string == '':
-            return None
+    if string is None or string == '':
+        return None
+
+    if string.isnumeric():
         return int(string)
-    except:
-        try:
-            return clean_float(string)
-        except:
-            return string
+
+    try:
+        return clean_float(string)
+    except Exception:
+        return string
 
 
 def splitRecursive(word, tokens):
@@ -147,18 +148,19 @@ def hashtext(cell):
 
 
 def _is_foreign_key_name(name):
-    for endings in ['-id', '_id', 'ID', 'Id']:
+    for endings in ['id', 'ID', 'Id']:
+        for add in ['-','_', ' ']:
+            if name.endswith(add + endings):
+                return True
+    for endings in ['ID', 'Id']:
         if name.endswith(endings):
             return True
+    return False
 
+def _is_identifier_name(name):
     for keyword in ['account', 'uuid', 'identifier', 'user']:
         if keyword in name:
             return True
-
-    for keyword in ['id']:
-        if keyword == name:
-            return True
-
     return False
 
 
@@ -168,104 +170,97 @@ def isascii(string):
     """
     return all(ord(c) < 128 for c in string)
 
+def extract_digits(point):
+    return ''.join([char for char in str(point) if char.isdigit()])
 
-def get_identifier_description(data, column_name, data_subtype, other_potential_subtypes):
+def get_pct_auto_increment(data):
+    data = sorted(data)
+    prev = None
+    increase_by_one = 0
+    for point in data:
+        digits = extract_digits(point)
+        if prev is not None and digits is not None:
+            try:
+                diff = int(digits) - int(prev)
+                if diff == 1:
+                    increase_by_one += 1
+            except Exception:
+                pass
+
+        prev = digits
+    return increase_by_one/(len(data) - 1)
+
+def get_identifier_description(data, column_name, data_type, data_subtype, other_potential_subtypes):
     data = list(data)
+    unquie_pct = len(set(data))/len(data)
 
-    foregin_key_type = DATA_SUBTYPES.INT in [*other_potential_subtypes, data_subtype]
+    # Detect auto incrementing index
+    if data_subtype == DATA_SUBTYPES.INT:
+        if get_pct_auto_increment(data) > 0.98 and unquie_pct > 0.99:
+            return 'Auto-incrementing identifier'
 
-    if foregin_key_type:
-        prev = None
-        for x in map(lambda val: int(float(val)), sorted(data)):
-            if prev is None:
-                prev = x
-            else:
-                if (x - prev) != 1:
-                    break
-                else:
-                    prev = x
-        else:
-            return 'Auto-incrementing Identifier'
-
-    # Detect UUID
-    if foregin_key_type:
-        is_uuid = False
-    else:
-        all_same_length = all(len(str(data[0])) == len(str(x)) for x in data)
-        uuid_charset = set('0123456789abcdefABCDEF-')
-        all_uuid_charset = all(set(str(x)).issubset(uuid_charset) for x in data)
-        is_uuid = all_uuid_charset and all_same_length
-
-
-        # If all data points are strings of equal length
-        # then compute entropy per each index through all data
-        #
-        # Example:
-        #
-        #   column
-        # 1 'wqk5'
-        # 2 'wq6z'
-        # 3 'wqv7'
-        # 4 'eq8O'
-        # 5 'eqkO'
-        # 6 'eqyS'
-        # 7 'eqAe' 
-        #    ||||
-        #    ||||-------------------- index 3
-        #    |||                      Counter({5: 1, z: 1, 7: 1, O: 2, s: 1, e: 1})
-        #    |||                      S = entropy[1, 1, 1, 2, 1, 1]
-        #    |||                      randomness = S / np.log(6) <----- 6 unique values at this index
-        #    |||
-        #    |||--------------------- index 2
-        #    ||                       Counter({k: 2, 6: 1, v: 1, 8: 1, Y: 1, A: 1})
-        #    ||                       S = entropy[2, 1, 1, 1, 1, 1]
-        #    ||                       randomness = S / np.log(6) <----- 6 unique values at this index
-        #    ||
-        #    ||---------------------- index 1
-        #    |                        Counter({q: 7})
-        #    |                        S = entropy[7]
-        #    |                        randomness = S / np.log(1) <----- 1 unique value at this index
-        #    |
-        #    |----------------------- index 0
-        #                             Counter({w: 3, e: 4})
-        #                             S = entropy[3, 4]
-        #                             randomness = S / np.log(2) <----- 2 unique values at this index
-        #
+    # Detect hash
+    all_same_length = all(len(str(data[0])) == len(str(x)) for x in data)
+    uuid_charset = set('0123456789abcdefABCDEF-')
+    all_uuid_charset = all(set(str(x)).issubset(uuid_charset) for x in data)
+    is_uuid = all_uuid_charset and all_same_length
+    
+    if all_same_length and len(data) == len(set(data)):
+        str_data = [str(x) for x in data]
+        # If all data points are strings of equal length	
+        # then compute entropy per each index through all data	
+        #	
+        # Example:	
+        #	
+        #   column	
+        # 1 'wqk5'	
+        # 2 'wq6z'	
+        # 3 'wqv7'	
+        # 4 'eq8O'	
+        # 5 'eqkO'	
+        # 6 'eqyS'	
+        # 7 'eqAe' 	
+        #    ||||	
+        #    ||||-------------------- index 3	
+        #    |||                      Counter({5: 1, z: 1, 7: 1, O: 2, s: 1, e: 1})	
+        #    |||                      S = entropy[1, 1, 1, 2, 1, 1]	
+        #    |||                      randomness = S / np.log(6) <----- 6 unique values at this index	
+        #    |||	
+        #    |||--------------------- index 2	
+        #    ||                       Counter({k: 2, 6: 1, v: 1, 8: 1, Y: 1, A: 1})	
+        #    ||                       S = entropy[2, 1, 1, 1, 1, 1]	
+        #    ||                       randomness = S / np.log(6) <----- 6 unique values at this index	
+        #    ||	
+        #    ||---------------------- index 1	
+        #    |                        Counter({q: 7})	
+        #    |                        S = entropy[7]	
+        #    |                        randomness = S / np.log(1) <----- 1 unique value at this index	
+        #    |	
+        #    |----------------------- index 0	
+        #                             Counter({w: 3, e: 4})	
+        #                             S = entropy[3, 4]	
+        #                             randomness = S / np.log(2) <----- 2 unique values at this index	
+        #	
         # Scaling entropy by np.log(num_of_unique_values) produces a number in range [0, 1]
-        #
+        randomness_per_index = []
+        for i, _ in enumerate(str_data[0]):
+            N = len(set(x[i] for x in str_data))
+            S = st.entropy([*Counter(x[i] for x in str_data).values()])
+            randomness_per_index.append(S / np.log(N))
 
-        if all_same_length and len(data) == len(set(data)):
-            str_data = [str(x) for x in data]
-            
-            randomness_per_index = []
-            for i, _ in enumerate(str_data[0]):
-                N = len(set(x[i] for x in str_data))
-                S = st.entropy([*Counter(x[i] for x in str_data).values()])
-                randomness_per_index.append(S / np.log(N))
+        if np.mean(randomness_per_index) > 0.95:
+            return 'Hash-like identifier'
 
-            if np.mean(randomness_per_index) > 0.95:
-                return 'Hash-like identifier'
+    # Detect foreign key
+    if data_subtype == DATA_SUBTYPES.INT:
+        if _is_foreign_key_name(column_name):
+            return 'Foregin key'
 
-    '''
-    tiny_and_distinct = True
-    for val in data:
-        for splitter in [' ', ',', '\t', '|', '#', '.']:
-            if len(str(val).split(splitter)) > 1:
-                tiny_and_distinct = False
-
-    if len(list(set(data))) + 1 < len(data):
-        tiny_and_distinct = False
-    '''
-    tiny_and_distinct = False
-
-    if _is_foreign_key_name(column_name):
-        if foregin_key_type:
-            return 'Identifier'
-
-        if is_uuid:
-            return 'UUID'
-
-    if DATA_SUBTYPES.INT == data_subtype and tiny_and_distinct:
-        return 'Identifier'
+    if _is_identifier_name(column_name) or data_type == DATA_TYPES.CATEGORICAL:
+        if unquie_pct > 0.98:
+            if is_uuid:
+                return 'UUID'
+            else:
+                return 'Unknown identifier'
 
     return None
